# ase-parser
Parse Aseprite files with Node.js, no external dependencies


## Aseprite Object
| Field        | Type                   | Description                            |
|--------------|------------------------|----------------------------------------|
| frames       | array of [frame](#frame-object) objects | frames                                 |
| layers       | array of [layer](#layer-object) objects | layers                                 |
| fileSize     | integer                | size of the file (in bytes)            |
| numFrames    | integer                | number of frames the Aseprite file has |
| width        | integer                | width (in pixels)                      |
| height       | integer                | height (in pixels)                     |
| colorDepth   | integer                | color depth (in bits per pixel)        |
| numColors    | integer                | number of colors                       |
| pixelRatio   | string                 | width:height                           |
| name         | string                 | name of the file                       |
| tags         | arry of [tag](#tag-object) objects    | tags                                   |
| colorProfile | [colorProfile](#color-profile-object) object    | Color profile                          |
| palette      | [palette](#palette-object) object         | Palette                                |

## Frame Object
| Field         | Type                  | Description      |
|---------------|-----------------------|------------------|
| bytesInFrame  | integer               | size (in bytes)  |
| frameDuration | integer               | duration (in ms) |
| cels          | array of [cel](#cel-object) objects | cels             |

## Layer Object
| Field           | Type    | Description         |
|-----------------|---------|---------------------|
| flags           | integer | flags for the layer |
| type            | integer | type                |
| layerChildLevel | integer | layer child level   |
| opacity         | integer | opacity (0-255)     |
| name            | string  | name of layer       |


## Tag Object
| Field         | Type    | Description                            |
|---------------|---------|----------------------------------------|
| from          | integer | first frame index                    |
| to            | integer | last frame index                     |
| animDirection | string  | `Forward`, `Reverse` or `Ping-pong`    |
| color         | string  | hex color of the tag (no `#` included) |
| name          | string  | name                                   |

## Color Profile Object
| Field  | Type    | Description             |
|--------|---------|-------------------------|
| type   | string  | `None`, `sRGB` or `ICC` |
| flag   | integer | fixed gamma flag        |
| fGamma | integer | fixed gamma             |
| icc?   | buffer  | ICC profile data        |

## Palette Object
| Field       | Type                   | Description              |
|-------------|------------------------|--------------------------|
| paletteSize | integer                | number of colors         |
| firstColor  | integer                | index of the first color |
| lastColor   | integer                | index of the last color  |
| colors      | array of [color](#color-object) objects | colors                   |

## Cel Object
| Field      | Type    | Description                                  |
|------------|---------|----------------------------------------------|
| layerIndex | integer | index of the layer associated                |
| xpos       | integer | x position of the cel compared to the sprite |
| ypos       | integer | y position of the cel compared to the sprite |
| opacity    | integer | opacity (0-255)                              |
| celType    | integer | internally used                              |
| w          | integer | width (in pixels)                            |
| h          | integer | height (in pixels)                           |
| rawCelData | Buffer  | raw cel pixel data                           |

## Color Object
| Field | Type    | Description                                   |
|-------|---------|-----------------------------------------------|
| red   | integer | red value (0-255)                             |
| green | integer | green value (0-255)                           |
| blue  | integer | blue value (0-255)                            |
| alpha | integer | alpha value (0-255)                           |
| name  | string  | 'none' or the actual color name if it has one |

# Further Info

If you would like to read up on the Aseprite file spec: [Spec](https://github.com/aseprite/aseprite/blob/master/docs/ase-file-specs.md)